@@ -16,13 +16,19 @@ echo autoheader...
 
 autoheader
 
-echo libtoolize...
-(libtoolize --version) < /dev/null > /dev/null 2>&1 || {
-    echo libtoolize not found
-    exit 1
-}
+echo -n "libtoolize... "
+if ( (glibtoolize --version) < /dev/null > /dev/null 2>&1 ); then
+    echo "using glibtoolize"
+    glibtoolize --automake --copy --force
 
-libtoolize --automake --copy --force
+elif ( (libtoolize --version) < /dev/null > /dev/null 2>&1 ) ; then
+    echo "using libtoolize"
+    libtoolize --automake --copy --force
+
+else
+    echo "libtoolize nor glibtoolize not found"
+    exit 1
+fi
 
 echo automake...
 (automake --version) < /dev/null > /dev/null 2>&1 || {
