@@ -79,8 +79,11 @@ private:
 DhtServer::DhtServer(DhtRouter* router) :
   m_router(router),
 
-  m_uploadThrottle(60),
-  m_downloadThrottle(60),
+  m_uploadNode(60),
+  m_downloadNode(60),
+
+  m_uploadThrottle(manager->upload_throttle()->throttle_list()),
+  m_downloadThrottle(manager->download_throttle()->throttle_list()),
 
   m_networkUp(false) {
 
@@ -125,11 +128,11 @@ DhtServer::start(int port) {
 
   m_taskTimeout.set_slot(rak::mem_fn(this, &DhtServer::receive_timeout));
 
-  m_uploadThrottle.set_list_iterator(manager->upload_throttle()->throttle_list()->end());
-  m_uploadThrottle.slot_activate(rak::make_mem_fun(static_cast<SocketBase*>(this), &SocketBase::receive_throttle_up_activate));
+  m_uploadNode.set_list_iterator(m_uploadThrottle->end());
+  m_uploadNode.slot_activate(rak::make_mem_fun(static_cast<SocketBase*>(this), &SocketBase::receive_throttle_up_activate));
 
-  m_downloadThrottle.set_list_iterator(manager->download_throttle()->throttle_list()->end());
-  manager->download_throttle()->throttle_list()->insert(&m_downloadThrottle);
+  m_downloadNode.set_list_iterator(m_downloadThrottle->end());
+  m_downloadThrottle->insert(&m_downloadNode);
 
   manager->poll()->open(this);
   manager->poll()->insert_read(this);
@@ -145,8 +148,8 @@ DhtServer::stop() {
 
   priority_queue_erase(&taskScheduler, &m_taskTimeout);
 
-  manager->upload_throttle()->throttle_list()->erase(&m_uploadThrottle);
-  manager->download_throttle()->throttle_list()->erase(&m_downloadThrottle);
+  m_uploadThrottle->erase(&m_uploadNode);
+  m_downloadThrottle->erase(&m_downloadNode);
 
   manager->poll()->remove_read(this);
   manager->poll()->remove_write(this);
@@ -165,8 +168,8 @@ DhtServer::reset_statistics() {
   m_queriesSent = 0;
   m_repliesReceived = 0;
 
-  m_uploadThrottle.rate()->set_total(0);
-  m_downloadThrottle.rate()->set_total(0);
+  m_uploadNode.rate()->set_total(0);
+  m_downloadNode.rate()->set_total(0);
 }
 
 // Ping a node whose ID we know.
@@ -302,8 +305,7 @@ DhtServer::create_get_peers_response(const Object& arg, const rak::socket_addres
     reply.insert_key("nodes", std::string(compact, end));
 
   } else {
-    Object& values = reply.insert_key("values", Object::create_list());
-    values.insert_back(tracker->get_peers());
+    reply.insert_key("values", Object::create_list()).as_list().swap(tracker->get_peers().as_list());
   }
 }
 
@@ -336,36 +338,44 @@ DhtServer::process_response(int transactionId, const HashString& id, const rak::
   m_repliesReceived++;
   m_networkUp = true;
 
-  DhtTransaction* transaction = itr->second;
+  // Make sure transaction is erased even if an exception is thrown.
+  try {
+    DhtTransaction* transaction = itr->second;
 #ifdef USE_EXTRA_DEBUG
-  if (DhtTransaction::key(sa, transactionId) != transaction->key(transactionId))
-    throw internal_error("DhtServer::process_response key mismatch.");
+    if (DhtTransaction::key(sa, transactionId) != transaction->key(transactionId))
+      throw internal_error("DhtServer::process_response key mismatch.");
 #endif
 
-  // If we contact a node but its ID is not the one we expect, ignore the reply
-  // to prevent interference from rogue nodes.
-  if ((id != transaction->id() && transaction->id() != m_router->zero_id))
-    return;
+    // If we contact a node but its ID is not the one we expect, ignore the reply
+    // to prevent interference from rogue nodes.
+    if ((id != transaction->id() && transaction->id() != m_router->zero_id))
+      return;
 
-  const Object& response = request.get_key("r");
+    const Object& response = request.get_key("r");
 
-  switch (transaction->type()) {
-    case DhtTransaction::DHT_FIND_NODE:
-      parse_find_node_reply(transaction->as_find_node(), response.get_key_string("nodes"));
-      break;
+    switch (transaction->type()) {
+      case DhtTransaction::DHT_FIND_NODE:
+        parse_find_node_reply(transaction->as_find_node(), response.get_key_string("nodes"));
+        break;
 
-    case DhtTransaction::DHT_GET_PEERS:
-      parse_get_peers_reply(transaction->as_get_peers(), response);
-      break;
+      case DhtTransaction::DHT_GET_PEERS:
+        parse_get_peers_reply(transaction->as_get_peers(), response);
+        break;
 
-    // Nothing to do for DHT_PING and DHT_ANNOUNCE_PEER
-    default:
-      break;
+      // Nothing to do for DHT_PING and DHT_ANNOUNCE_PEER
+      default:
+        break;
+    }
+
+    // Mark node responsive only if all processing was successful, without errors.
+    m_router->node_replied(id, sa);
+
+  } catch (std::exception& e) {
+    delete itr->second;
+    m_transactions.erase(itr);
+    throw;
   }
 
-  // Mark node responsive only if all processing was successful, without errors.
-  m_router->node_replied(id, sa);
-
   delete itr->second;
   m_transactions.erase(itr);
 }
@@ -417,7 +427,7 @@ DhtServer::parse_get_peers_reply(DhtTransactionGetPeers* transaction, const Obje
   transaction->complete(true);
 
   if (response.has_key_list("values"))
-    announce->receive_peers((*response.get_key_list("values").begin()).as_string());
+    announce->receive_peers(response.get_key("values"));
 
   if (response.has_key_string("token"))
     add_transaction(new DhtTransactionAnnouncePeer(transaction->id(), transaction->address(), announce->target(), response.get_key_string("token")), packet_prio_low);
@@ -612,7 +622,17 @@ DhtServer::failed_transaction(transaction_itr itr, bool quick) {
     else
       transaction->as_find_node()->complete(false);
 
-    find_node_next(transaction->as_find_node());
+    try {
+      find_node_next(transaction->as_find_node());
+
+    } catch (std::exception& e) {
+      if (!quick) {
+        delete itr->second;
+        m_transactions.erase(itr);
+      }
+
+      throw;
+    }
   }
 
   if (quick) {
@@ -641,6 +661,7 @@ DhtServer::event_read() {
   sstream.imbue(std::locale::classic());
 
   while (true) {
+    Object request;
     rak::socket_address sa;
     int type = '?';
     const Object* transactionId = NULL;
@@ -656,7 +677,6 @@ DhtServer::event_read() {
       total += read;
       sstream.str(std::string(buffer, read));
 
-      Object request;
       sstream >> request;
 
       // If it's not a valid bencode dictionary at all, it's probably not a DHT
@@ -733,8 +753,8 @@ DhtServer::event_read() {
     }
   }
 
-  manager->download_throttle()->throttle_list()->node_used_unthrottled(total);
-  m_downloadThrottle.rate()->insert(total);
+  m_downloadThrottle->node_used_unthrottled(total);
+  m_downloadNode.rate()->insert(total);
 
   start_write();
 }
@@ -756,7 +776,7 @@ DhtServer::process_queue(packet_queue& queue, uint32_t* quota) {
     }
 
     if (packet->length() > *quota) {
-      manager->upload_throttle()->throttle_list()->node_used(&m_uploadThrottle, used);
+      m_uploadThrottle->node_used(&m_uploadNode, used);
       return false;
     }
 
@@ -791,7 +811,7 @@ DhtServer::process_queue(packet_queue& queue, uint32_t* quota) {
     delete packet;
   }
 
-  manager->upload_throttle()->throttle_list()->node_used(&m_uploadThrottle, used);
+  m_uploadThrottle->node_used(&m_uploadNode, used);
   return true;
 }
 
@@ -800,18 +820,18 @@ DhtServer::event_write() {
   if (m_highQueue.empty() && m_lowQueue.empty())
     throw internal_error("DhtServer::event_write called but both write queues are empty.");
 
-  if (!manager->upload_throttle()->throttle_list()->is_throttled(&m_uploadThrottle))
+  if (!m_uploadThrottle->is_throttled(&m_uploadNode))
     throw internal_error("DhtServer::event_write called while not in throttle list.");
 
-  uint32_t quota = manager->upload_throttle()->throttle_list()->node_quota(&m_uploadThrottle);
+  uint32_t quota = m_uploadThrottle->node_quota(&m_uploadNode);
 
   if (quota == 0 || !process_queue(m_highQueue, &quota) || !process_queue(m_lowQueue, &quota)) {
     manager->poll()->remove_write(this);
-    manager->upload_throttle()->throttle_list()->node_deactivate(&m_uploadThrottle);
+    m_uploadThrottle->node_deactivate(&m_uploadNode);
 
   } else if (m_highQueue.empty() && m_lowQueue.empty()) {
     manager->poll()->remove_write(this);
-    manager->upload_throttle()->throttle_list()->erase(&m_uploadThrottle);
+    m_uploadThrottle->erase(&m_uploadNode);
   }
 }
 
@@ -821,8 +841,8 @@ DhtServer::event_error() {
 
 void
 DhtServer::start_write() {
-  if ((!m_highQueue.empty() || !m_lowQueue.empty()) && !manager->upload_throttle()->throttle_list()->is_throttled(&m_uploadThrottle)) {
-    manager->upload_throttle()->throttle_list()->insert(&m_uploadThrottle);
+  if ((!m_highQueue.empty() || !m_lowQueue.empty()) && !m_uploadThrottle->is_throttled(&m_uploadNode)) {
+    m_uploadThrottle->insert(&m_uploadNode);
     manager->poll()->insert_write(this);
   }
 
