@@ -104,13 +104,15 @@ public:
   FileList*           file_list()                                { return &m_fileList; }
   PeerList*           peer_list()                                { return &m_peerList; }
 
+  std::pair<ThrottleList*, ThrottleList*> throttles(const sockaddr* sa);
+
   ThrottleList*       upload_throttle()                          { return m_uploadThrottle; }
   void                set_upload_throttle(ThrottleList* t)       { m_uploadThrottle = t; }
 
   ThrottleList*       download_throttle()                        { return m_downloadThrottle; }
   void                set_download_throttle(ThrottleList* t)     { m_downloadThrottle = t; }
 
-  DataBuffer          get_ut_pex(bool initial)                   { return initial ? m_ut_pex_initial : m_ut_pex_delta; }
+  DataBuffer          get_ut_pex(bool initial)                   { return (initial ? m_ut_pex_initial : m_ut_pex_delta).clone(); }
 
   bool                want_pex_msg()                             { return m_info->is_pex_active() && m_peerList.available_list()->want_more(); }; 
 
@@ -129,6 +131,8 @@ public:
   void                slot_count_handshakes(SlotCountHandshakes s) { m_slotCountHandshakes = s; }
   void                slot_hash_check_add(SlotHashCheckAdd s)      { m_slotHashCheckAdd = s; }
 
+  void                add_peer(const rak::socket_address& sa);
+
   void                receive_connect_peers();
   void                receive_chunk_done(unsigned int index);
   void                receive_corrupt_chunk(PeerInfo* peerInfo);
