@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -62,12 +62,11 @@ Listen::open(uint16_t first, uint16_t last, const rak::socket_address* bindAddre
       bindAddress->family() != rak::socket_address::af_inet6)
     throw input_error("Listening socket must be bound to an inet or inet6 address.");
 
-  if (!get_fd().open_stream() || !get_fd().set_nonblock())
+  if (!get_fd().open_stream() ||
+      !get_fd().set_nonblock() ||
+      !get_fd().set_reuse_address(true))
     throw resource_error("Could not allocate socket for listening.");
 
-  if (!get_fd().set_reuse_address(true))
-    throw resource_error("Could not set listening port to reuse address.");
-
   rak::socket_address sa;
   sa.copy(*bindAddress, bindAddress->length());
 
@@ -126,7 +125,7 @@ Listen::event_write() {
 
 void
 Listen::event_error() {
-  throw resource_error("Listener port received an error event.");
+  throw internal_error("Listener port received an error event.");
 }
 
 }
