@@ -133,15 +133,14 @@ void
 Handshake::initialize_outgoing(const rak::socket_address& sa, DownloadMain* d, PeerInfo* peerInfo) {
   m_download = d;
 
-  m_uploadThrottle = d->upload_throttle();
-  m_downloadThrottle = d->download_throttle();
-
   m_peerInfo = peerInfo;
   m_peerInfo->set_flags(PeerInfo::flag_handshake);
 
   m_incoming = false;
   m_address = sa;
 
+  std::make_pair(m_uploadThrottle, m_downloadThrottle) = m_download->throttles(m_address.c_sockaddr());
+
   m_state = CONNECTING;
 
   manager->poll()->open(this);
@@ -347,8 +346,7 @@ Handshake::read_encryption_skey() {
 
   validate_download();
 
-  m_uploadThrottle = m_download->upload_throttle();
-  m_downloadThrottle = m_download->download_throttle();
+  std::make_pair(m_uploadThrottle, m_downloadThrottle) = m_download->throttles(m_address.c_sockaddr());
 
   m_encryption.initialize_encrypt(m_download->info()->hash().c_str(), m_incoming);
   m_encryption.initialize_decrypt(m_download->info()->hash().c_str(), m_incoming);
@@ -495,8 +493,7 @@ Handshake::read_info() {
 
     validate_download();
 
-    m_uploadThrottle = m_download->upload_throttle();
-    m_downloadThrottle = m_download->download_throttle();
+    std::make_pair(m_uploadThrottle, m_downloadThrottle) = m_download->throttles(m_address.c_sockaddr());
 
     prepare_handshake();
 
@@ -1016,8 +1013,8 @@ Handshake::prepare_peer_info() {
     if (m_peerInfo == NULL)
       throw handshake_error(ConnectionManager::handshake_failed, e_handshake_network_error);
 
-    if (m_peerInfo->failed_counter() > 10)
-      throw handshake_error(ConnectionManager::handshake_dropped, e_handshake_unwanted_connection);
+    if (m_peerInfo->failed_counter() > m_manager->max_failed)
+      throw handshake_error(ConnectionManager::handshake_dropped, e_handshake_toomanyfailed);
 
     m_peerInfo->set_flags(PeerInfo::flag_handshake);
   }
