@@ -137,7 +137,7 @@ HandshakeManager::create_outgoing(const rak::socket_address& sa, DownloadMain* d
   PeerInfo* peerInfo = download->peer_list()->connected(sa.c_sockaddr(),
                                                         PeerList::connect_keep_handshakes | PeerList::connect_filter_recent);
 
-  if (peerInfo == NULL)
+  if (peerInfo == NULL || peerInfo->failed_counter() > max_failed)
     return;
 
   SocketFd fd;
