@@ -44,14 +44,13 @@
 #include "torrent.h"
 #include "object.h"
 #include "object_stream.h"
+#include "throttle.h"
 #include "connection_manager.h"
 #include "poll.h"
 
 #include "manager.h"
 #include "resource_manager.h"
 
-#include "net/throttle_list.h"
-#include "net/throttle_manager.h"
 #include "protocol/handshake_manager.h"
 #include "protocol/peer_factory.h"
 #include "data/file_manager.h"
@@ -60,9 +59,40 @@
 #include "download/download_constructor.h"
 #include "download/download_manager.h"
 #include "download/download_wrapper.h"
+#include "torrent/peer/connection_list.h"
 
 namespace torrent {
 
+// A preliminary implementation of a global lock, to be moved
+// somewhere more appropriate when it's put to use.
+
+// pthread_mutex_t m_globalLock __cacheline_alinged;
+
+// void
+// acquire_global_lock() {
+//   int err;
+
+//   __sync_add_and_fetch(&this->m_globalWaiting, 1);
+
+//   if ((err = pthread_mutex_lock(&this->m_globalLock)))
+//     throw internal_error("Mutex failed.");
+  
+//   __sync_fetch_and_sub(&this->m_globalWaiting, 1);
+// }
+
+// void
+// release_global_lock() {
+//   pthread_mutex_unlock(&this->m_globalLock);
+// }
+
+// void
+// waive_global_lock() {
+//   pthread_mutex_unlock(&this->m_globalLock);
+
+//   // Do we need to sleep here? Make a CppUnit test for this.
+//   acquire_global_lock();
+// }
+
 uint32_t
 calculate_max_open_files(uint32_t openMax) {
   if (openMax >= 8096)
@@ -165,6 +195,13 @@ connection_manager() {
   return manager->connection_manager();
 }
 
+DhtManager*
+dht_manager() {
+  return manager->dht_manager();
+}
+
+//TaskManager* task_manager() { return manager->task_manager(); }
+
 uint32_t
 total_handshakes() {
   return manager->handshake_manager()->size();
@@ -180,30 +217,14 @@ next_timeout() {
     return rak::timer::from_seconds(60).usec();
 }
 
-int32_t
-down_throttle() {
-  return manager->download_throttle()->max_rate();
+Throttle*
+down_throttle_global() {
+  return manager->download_throttle();
 }
 
-void
-set_down_throttle(int32_t bytes) {
-  if (bytes < 0 || bytes > (1 << 30))
-    throw input_error("Download throttle must be between 0 and 2^30.");
-
-  return manager->download_throttle()->set_max_rate(bytes);
-}
-
-int32_t
-up_throttle() {
-  return manager->upload_throttle()->max_rate();
-}
-
-void
-set_up_throttle(int32_t bytes) {
-  if (bytes < 0 || bytes > (1 << 30))
-    throw input_error("Upload throttle must be between 0 and 2^30.");
-
-  return manager->upload_throttle()->set_max_rate(bytes);
+Throttle*
+up_throttle_global() {
+  return manager->upload_throttle();
 }
 
 uint32_t
@@ -244,12 +265,12 @@ set_max_download_unchoked(uint32_t count) {
 
 const Rate*
 down_rate() {
-  return manager->download_throttle()->throttle_list()->rate_slow();
+  return manager->download_throttle()->rate();
 }
 
 const Rate*
 up_rate() {
-  return manager->upload_throttle()->throttle_list()->rate_slow();
+  return manager->upload_throttle()->rate();
 }
 
 const char*
